@@ -2,21 +2,18 @@ import logging
 import typing
 
 from cqrs import requests, response
+from cqrs.middlewares import base
 
 Req = typing.TypeVar("Req", bound=requests.Request, contravariant=True)
 Res = typing.TypeVar("Res", response.Response, None, covariant=True)
 HandleType = typing.Callable[[Req], typing.Awaitable[Res]]
 
+logger = logging.getLogger("cqrs")
 
-class LoggingMiddleware:
-    def __init__(
-        self,
-        logger: logging.Logger | None = None,
-    ) -> None:
-        self._logger = logger or logging.getLogger("cqrs")
 
-    async def __call__(self, request: Req, handle: HandleType) -> Res:
-        self._logger.debug(
+class LoggingMiddleware(base.Middleware):
+    async def __call__(self, request: requests.Request, handle: HandleType) -> Res:
+        logger.debug(
             "Handle %s request",
             type(request).__name__,
             extra={
@@ -25,11 +22,13 @@ class LoggingMiddleware:
             },
         )
         resp = await handle(request)
-        self._logger.debug(
+        logger.debug(
             "Request %s handled",
             type(request).__name__,
             extra={
-                "request_json_fields": {"response": resp.model_dump(mode="json") if resp else {}},
+                "request_json_fields": {
+                    "response": resp.model_dump(mode="json") if resp else {},
+                },
                 "to_mask": True,
             },
         )
